@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-01-23'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2016-02-22'; # DATE
+our $VERSION = '0.55'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -391,11 +391,26 @@ sub _process_script {
         last unless $cli->{subcommands};
 
         my @content;
+        my %sc_spec_refs; # key=ref address, val=first subcommand name
         for my $sc_name (sort keys %clidocdata) {
             my $sc_spec = $cli->{subcommands}{$sc_name};
+
+            my $spec_same_as;
+            if (defined $sc_spec_refs{"$sc_spec"}) {
+                $spec_same_as = $sc_spec_refs{"$sc_spec"};
+            } else {
+                $sc_spec_refs{"$sc_spec"} = $sc_name;
+            }
+
             my $meta = $metas{$sc_name};
             push @content, "=head2 B<$sc_name>\n\n";
 
+            # assumed alias because spec has been seen before
+            if ($spec_same_as) {
+                push @content, "Alias for C<$spec_same_as>.\n\n";
+                next;
+            }
+
             my $summary = $sc_spec->{summary} // $meta->{summary};
             push @content, "$summary.\n\n" if $summary;
 
@@ -467,9 +482,19 @@ sub _process_script {
 
             # display each subcommand's options (without the options tagged as
             # 'common')
+            my %sc_spec_refs;
             for my $sc_name (@sc_names) {
                 my $sc_spec = $cli->{subcommands}{$sc_name};
+
+                my $spec_same_as;
+                if (defined $sc_spec_refs{"$sc_spec"}) {
+                    $spec_same_as = $sc_spec_refs{"$sc_spec"};
+                } else {
+                    $sc_spec_refs{"$sc_spec"} = $sc_name;
+                }
+                next if defined $spec_same_as;
                 next if $sc_spec->{is_alias};
+
                 my $opts = $clidocdata{$sc_name}{opts};
                 my @opts = sort {
                     (my $a_without_dash = $a) =~ s/^-+//;
@@ -770,7 +795,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.54 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-01-23.
+This document describes version 0.55 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-02-22.
 
 =head1 SYNOPSIS
 
